@@ -5,6 +5,19 @@ import os
 
 class TestOSDs(object):
 
+    def _get_osds_id(self, node, host):
+        osds = []
+        cmd = host.run('sudo ls /var/lib/ceph/osd/ | sed "s/.*-//"')
+        if cmd.rc == 0:
+            osds = cmd.stdout.rstrip("\n").split("\n")
+        return osds
+
+    def _get_docker_exec_cmd(self, node, host):
+        osd_id = host.check_output(
+            "{container_binary} ps -q --filter='name=ceph-osd' | head -1".format(container_binary=node['container_binary']))
+        return osd_id
+
+
     @pytest.mark.no_docker
     def test_ceph_osd_package_is_installed(self, node, host):
         assert host.package("ceph-osd").is_installed
@@ -17,23 +30,25 @@ class TestOSDs(object):
     def test_osds_listen_on_cluster_network(self, node, host):
         # TODO: figure out way to paramaterize this test
         nb_port = (node["num_osds"] * 2)
-        assert host.check_output("netstat -lntp | grep ceph-osd | grep %s | wc -l" % (node["cluster_address"])) == str(nb_port)
+        assert host.check_output("netstat -lntp | grep ceph-osd | grep %s | wc -l" % (host.interface("eth2").addresses[0])) == str(nb_port)
 
     def test_osd_services_are_running(self, node, host):
         # TODO: figure out way to paramaterize node['osds'] for this test
-        for osd in node["osds"]:
+#        for osd in node["osds"]:
+        for osd in self._get_osds_id(node, host):
             assert host.service("ceph-osd@%s" % osd).is_running
 
     @pytest.mark.no_lvm_scenario
     def test_osd_services_are_enabled(self, node, host):
         # TODO: figure out way to paramaterize node['osds'] for this test
-        for osd in node["osds"]:
+#        for osd in node["osds"]:
+        for osd in self._get_osds_id(node, host):
             assert host.service("ceph-osd@%s" % osd).is_enabled
 
     @pytest.mark.no_docker
     def test_osd_are_mounted(self, node, host):
         # TODO: figure out way to paramaterize node['osd_ids'] for this test
-        for osd_id in node["osd_ids"]:
+        for osd_id in self._get_osds_id(node, host):
             osd_path = "/var/lib/ceph/osd/{cluster}-{osd_id}".format(
                 cluster=node["cluster_name"],
                 osd_id=osd_id,
@@ -71,11 +86,11 @@ class TestOSDs(object):
 
     @pytest.mark.docker
     def test_all_docker_osds_are_up_and_in(self, node, host):
-        osd_id = host.check_output(
-            "docker ps -q --filter='name=ceph-osd' | head -1")
-        cmd = "sudo docker exec {osd_id} ceph --cluster={cluster} --connect-timeout 5 --keyring /var/lib/ceph/bootstrap-osd/{cluster}.keyring -n client.bootstrap-osd osd tree -f json".format(
-            osd_id=osd_id,
+        container_binary= node['container_binary']
+        cmd = "sudo {container_binary} exec {osd_id} ceph --cluster={cluster} --connect-timeout 5 --keyring /var/lib/ceph/bootstrap-osd/{cluster}.keyring -n client.bootstrap-osd osd tree -f json".format(
+            container_binary=container_binary,
+            osd_id=self._get_docker_exec_cmd(node, host),
             cluster=node["cluster_name"]
         )
         output = json.loads(host.check_output(cmd))
-        assert node["num_osds"] == self._get_nb_up_osds_from_ids(node, output)
+        assert node["num_osds"] == self._get_nb_up_osds_from_ids(node, output)
\ No newline at end of file
